==> cyphesis-snapshot-1999.01.15.tar.gz: cyphesis/cyphesis.py <==
#!/usr/bin/python -i

""" noname.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

import whrandom,time,sys,string,os,posix
from event import *
import mgoal,defworld,engine
from observe import observe


#w=defworld.default()
#farmer=w.minds[0]
#smith=w.minds[1]

#debug
def p(o): print o

def sc(x,min,max,s):
    res=int(s/(max-min)*(x-min))
    if res<0: res=0
    if res>=s: res=s-1
    return res

def display_text_screen(w):
    #print chr(27)+"[H",+chr(27)ESC[2JESC[HESC[1m 
    wait=0.0
    print chr(27)+"[H",w.time,"Count of minds:",len(w.minds)
    xmin=-500.0
    xmax=-xmin
    ymin=-200.0
    ymax=-ymin
    sizex=70
    sizey=20
    def scx(x, min=xmin, max=xmax, s=sizex): return sc(x,min,max,s)
    def scy(y, min=ymin, max=ymax, s=sizey): return sc(y,min,max,s)
    screen = [None]*sizex
    for i in range(sizex):
        screen[i] = ['.'] * sizey
    for t in w.things.get('smithy',[]):
        (x,y,z)=t.get_xyz()
        screen[scx(x)][scy(y)]='s'
    for t in w.things.get('house',[]):
        (x,y,z)=t.get_xyz()
        screen[scx(x)][scy(y)]='h'
    for m in w.minds:
        (x,y,z)=m.get_xyz()
        x,y=scx(x),scy(y)
        screen[x][y]=m.name[0]
        screen[x+1][y]=m.name[-1]
        if m.name[0]=='f' and not m.things.has_key('axe'):
            screen[x+2][y]='!'
            wait=0.3
        if not mgoal.have_home(m):
            screen[x+2][y]='?'
            wait=2.0
    for t in w.things.get('fire',[]):
        (x,y,z)=t.get_xyz()
        screen[scx(x)][scy(y)]='F'
        wait=1.0
    out=[]
    for y in range(sizey):
        for x in range(sizex):
            out.append(screen[x][y])
        out.append('\n')
    print string.join(out,'')
    time.sleep(wait)

def run(steps=1, print_deb=1, break_cond=lambda e:0, disp_cond=lambda e:0):
    empty_event=event("empty")
    for i in range(steps):
        events=w.run_step()
        if print_deb and len(events)>0:
            p(w.time)
            print events
        disp_flag=0
        for e in events:
            if e.command=="illegal":
                return (e,i)
            if break_cond(e):
                return (e,i)
            if disp_cond(e): disp_flag=1
        if disp_cond(empty_event) or disp_flag:
            display_text_screen(w)


def r(steps=1, print_deb=1, break_cond=lambda e:0, disp_cond=lambda e:0):
    res=run(steps,print_deb,break_cond,disp_cond)
    if res:
        print "At step",res[1],"happened:",res[0]
    print "Current status:",w.time
    for npc in w.minds:
        print npc.name, npc.place, npc.xyz, npc.current_jobs
    f=w.things.get('fire')
    if f: print f[0]

def always(e): return 1
def fire(e): return e.command=="fire"
def birth_death(e): return e.desc=="birth" or e.desc=="death"

def debug(break_cond, disp_cond=lambda e:0):
    r(48*100,0,break_cond,disp_cond)

def test_speed(cycles=48*10):
    start=time.clock()
    for i in range(cycles):
        events=w.run_step()
        for e in events:
            if e.desc=="birth" or e.desc=="death":
                print w.time,e.desc,`e.what`,"Total:",len(w.minds)
    end=time.clock()
    print "Time:",end-start

def dsp_old(steps=48*100):
    print chr(27)+"c"
    r(steps,0,disp_cond=always)

defult_steps=48*100
w=None
obs=None
#defult_steps=18
def rdsp(steps=defult_steps):
    global obs
    if not obs: obs=observe(1)
    obs.dsp(steps)

def dsp(steps=defult_steps):
    global obs
    if not obs:
        #def map_add(name,x,y,z):
        #    print "add",name,x,y,z
        #obs=observe(0,map_add=map_add)
        obs=observe(0)
        global w
        w=obs.eng.w
    obs.dsp(steps)

def txt(steps=1):
    global obs
    if not obs:
        obs=observe(0)
        global w
        w=obs.eng.w
    obs.text(steps)

def deb(): import pdb; pdb.pm()

#r(13)
#f=farmer
#r(5)
#s=smith

#whrandom.seed(1,2,7)  #1,2,3

print """To run one step, type txt()
To run many steps you can give parameter:
\tfor example txt(48) will run a whole day.
To use text graphics, type dsp()

h: house
s: smithy
F: house in fire
Two charactes: NPC name: first and last letter
        (farmer, farmer1, ..., smith, smith1, ...)

To start separate engine server, 
type "./server.py cyphesis" at another shell prompt
To test separate engine server, type rdsp()

To exit press Ctrl-D"""

## from thing import thing
## from house import house
## from fire import fire
## h=house('house','ordinary house','home',status=1.0)
## f=fire('fire','semilive thing',h,0.0)
## def d(): dsp(1)
## try:
##     posix.remove("world.log")
##     posix.remove("farmer.mind.log")
##     posix.remove("smith.mind.log")
## except os.error: pass
## txt(1)
## f=w.things['farmer'][0]
## fm=f.mind
## t=fm.things['axe'][0]
## fm.debug.set(1)
## sm=w.things['smith'][0].mind
## sm.debug.set(1)
## #txt(21)
## wd=w.debug.history
## fd=fm.debug.history
## #dsp(23)

==> cyphesis-snapshot-1999.02.13.tar.gz: cyphesis/cyphesis.py <==
#!/usr/bin/python -i

""" cyphesis.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

import whrandom,time,sys,string,os,posix
from event import *
import mgoal,defworld,engine,prob
from observe import observe


#w=defworld.default()
#farmer=w.minds[0]
#smith=w.minds[1]

#debug
def p(o): print o

def sc(x,min,max,s):
    res=int(s/(max-min)*(x-min))
    if res<0: res=0
    if res>=s: res=s-1
    return res

def display_text_screen(w):
    #print chr(27)+"[H",+chr(27)ESC[2JESC[HESC[1m 
    wait=0.0
    print chr(27)+"[H",w.time,"Count of minds:",len(w.minds)
    xmin=-500.0
    xmax=-xmin
    ymin=-200.0
    ymax=-ymin
    sizex=70
    sizey=20
    def scx(x, min=xmin, max=xmax, s=sizex): return sc(x,min,max,s)
    def scy(y, min=ymin, max=ymax, s=sizey): return sc(y,min,max,s)
    screen = [None]*sizex
    for i in range(sizex):
        screen[i] = ['.'] * sizey
    for t in w.things.get('smithy',[]):
        (x,y,z)=t.get_xyz()
        screen[scx(x)][scy(y)]='s'
    for t in w.things.get('house',[]):
        (x,y,z)=t.get_xyz()
        screen[scx(x)][scy(y)]='h'
    for m in w.minds:
        (x,y,z)=m.get_xyz()
        x,y=scx(x),scy(y)
        screen[x][y]=m.name[0]
        screen[x+1][y]=m.name[-1]
        if m.name[0]=='f' and not m.things.has_key('axe'):
            screen[x+2][y]='!'
            wait=0.3
        if not mgoal.have_home(m):
            screen[x+2][y]='?'
            wait=2.0
    for t in w.things.get('fire',[]):
        (x,y,z)=t.get_xyz()
        screen[scx(x)][scy(y)]='F'
        wait=1.0
    out=[]
    for y in range(sizey):
        for x in range(sizex):
            out.append(screen[x][y])
        out.append('\n')
    print string.join(out,'')
    time.sleep(wait)

def run(steps=1, print_deb=1, break_cond=lambda e:0, disp_cond=lambda e:0):
    empty_event=event("empty")
    for i in range(steps):
        events=w.run_step()
        if print_deb and len(events)>0:
            p(w.time)
            print events
        disp_flag=0
        for e in events:
            if e.command=="illegal":
                return (e,i)
            if break_cond(e):
                return (e,i)
            if disp_cond(e): disp_flag=1
        if disp_cond(empty_event) or disp_flag:
            display_text_screen(w)


def r(steps=1, print_deb=1, break_cond=lambda e:0, disp_cond=lambda e:0):
    res=run(steps,print_deb,break_cond,disp_cond)
    if res:
        print "At step",res[1],"happened:",res[0]
    print "Current status:",w.time
    for npc in w.minds:
        print npc.name, npc.place, npc.xyz, npc.current_jobs
    f=w.things.get('fire')
    if f: print f[0]

def always(e): return 1
def fire(e): return e.command=="fire"
def birth_death(e): return e.desc=="birth" or e.desc=="death"

def debug(break_cond, disp_cond=lambda e:0):
    r(prob.steps_per_day*100,0,break_cond,disp_cond)

def test_speed(cycles=prob.steps_per_day*10):
    start=time.clock()
    for i in range(cycles):
        events=w.run_step()
        for e in events:
            if e.desc=="birth" or e.desc=="death":
                print w.time,e.desc,`e.what`,"Total:",len(w.minds)
    end=time.clock()
    print "Time:",end-start

def dsp_old(steps=prob.steps_per_day*100):
    print chr(27)+"c"
    r(steps,0,disp_cond=always)

default_steps=prob.steps_per_day*100
w=None
obs=None
#default_steps=18

def init_obs(remote,invoke_steps):
    global obs
    if not obs:
        obs=observe(remote,invoke_steps)
        if not remote:
            global w
            w=obs.eng.w
        obs.load_default()

def rdsp(steps=default_steps):
    init_obs(1,0)
    obs.dsp(steps)

def dsp(steps=default_steps):
    init_obs(0,1)
    obs.dsp(steps)

def rtxt(steps=1):
    init_obs(1,0)
    obs.text(steps)

def txt(steps=1):
    init_obs(0,1)
    obs.text(steps)

def deb(): import pdb; pdb.pm()

#whrandom.seed(1,2,7)  #1,2,3

print """To run one step, type txt()
To run many steps you can give parameter:
\tfor example txt("""+`prob.steps_per_day`+""") will run a whole day.
To use text graphics, type dsp()

h: house
s: smithy
F: house in fire
Two charactes: NPC name: first and last letter
        (farmer, farmer1, ..., smith, smith1, ...)

To start separate engine server, 
type "./server.py cyphesis" at another shell prompt
To test separate engine server, type rdsp()

To exit press Ctrl-D"""

## from thing import thing
## from house import house
## from fire import fire
## h=house('house','ordinary house','home',status=1.0)
## f=fire('fire','semilive thing',h,0.0)
## def d(): dsp(1)
## try:
##     posix.remove("world.log")
##     posix.remove("farmer.mind.log")
##     posix.remove("smith.mind.log")
## except os.error: pass
## txt(1)
## f=w.things['farmer'][0]
## fm=f.mind
## t=fm.things['axe'][0]
## fm.debug.set(1)
## sm=w.things['smith'][0].mind
## sm.debug.set(1)
## #txt(21)
## wd=w.debug.history
## fd=fm.debug.history
## #dsp(23)

#import defworld
#w=defworld.default(1)
#f=w.id_dict['_Nisuf']
